@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -60,7 +48,7 @@ QJsonObject ConfigSerializer::serializeConfig(const ConfigPtr &config)
     obj[QLatin1String("features")] = static_cast<int>(config->supportedFeatures());
 
     QJsonArray outputs;
-    Q_FOREACH (const OutputPtr &output, config->outputs()) {
+    for (const OutputPtr &output : config->outputs()) {
         outputs.append(serializeOutput(output));
     }
     obj[QLatin1String("outputs")] = outputs;
@@ -98,11 +86,19 @@ QJsonObject ConfigSerializer::serializeOutput(const OutputPtr &output)
     obj[QLatin1String("replicationSource")] = output->replicationSource();
 
     QJsonArray modes;
-    Q_FOREACH (const ModePtr &mode, output->modes()) {
+    for (const ModePtr &mode : output->modes()) {
         modes.append(serializeMode(mode));
     }
     obj[QLatin1String("modes")] = modes;
 
+    if (output->capabilities() & Output::Capability::Overscan) {
+        obj[QLatin1String("overscan")] = static_cast<int>(output->overscan());
+    }
+
+    if (output->capabilities() & Output::Capability::Vrr) {
+        obj[QLatin1String("vrrPolicy")] = static_cast<int>(output->vrrPolicy());
+    }
+
     return obj;
 }
 
@@ -281,6 +277,10 @@ OutputPtr ConfigSerializer::deserializeOutput(const QDBusArgument &arg)
             }
             arg.endArray();
             output->setModes(modes);
+        } else if (key == QLatin1String("overscan")) {
+            output->setOverscan(value.toUInt());
+        } else if (key == QLatin1String("vrrPolicy")) {
+            output->setVrrPolicy(static_cast<Output::VrrPolicy>(value.toInt()));
         } else {
             qCWarning(KSCREEN) << "Invalid key in Output map: " << key;
             return OutputPtr();
